# MOVAL


A python package to evaluate model performance without the ground truth label.

## User Document

The latest documentation can be found [here](https://moval.readthedocs.io/en/latest/index.html).

## Reference

```
@article{li2022estimating,
  title={Estimating Model Performance under Domain Shifts with Class-Specific Confidence Scores},
  author={Li, Zeju and Kamnitsas, Konstantinos and Islam, Mobarakol and Chen, Chen and Glocker, Ben},
  journal={arXiv preprint arXiv:2207.09957},
  year={2022}
}
```